Performance Quoting APIs Change Log - Domains
Overview
Performance Quoting Domains APIs allow the management of Dynamic Filters. Dynamic filters are stored in a dedicated domain service which can only be administrated via APIs.
You will find below a change tracking section to see which and how the API changed between versions.
Current version: 1.5.2
Online Access to documentation (via Swagger)
APIs are available here:
https://quote.YOUR_REALM_URL.proscloud.com/quotex-public-api/docs/index.html?contract=domai ns&token=TOKEN
Replace YOUR_REALM_URL with your realm URL (ex: us1, eu1, etc.) Generate your token from AppPortal: View API User Access
The following roles have to be used to generate the token:
- DESIGNER: use this role for modeling APIs
- API_USER: use this role for runtime APIs
Version Change Tracking
Changes from version 1.5.1 to version 1.5.2
WHAT’S CHANGED
POST /domains/admin/domain/{domainName}/upload
Request:
Changed content type : multipart/form-data
- Changed property
importFile(string)
File to import must be plain JSON and have format like DomainsFileFormat defined in model part of this view. The file can also be a ZIP containing one JSON file as described. The ZIP version is mandatory for files greater than 100KB.
POST /domains/admin/domain/{domainName}/pushAndActivate
Request:
Changed content type : multipart/form-data
- Changed property
importFile(string)
File to import must be plain JSON and have format like DomainsFileFormat defined in model part of this view. The file can also be a ZIP containing one JSON file as described. The ZIP version is mandatory for files greater than 100KB.
Changes from version 1.5.0 to version 1.5.1
WHAT’S CHANGED
POST /domains/getdomain/{relationVariableId}
Request:
Changed content type : application/json
- Changed property
domain(object)
Domain definition contains the list of relations to include and restricted ranges if any.
- Changed property
restrictedRanges(array)Note: List of restricted ranges
Changed items (object):
POST /domains/checkConsistency/
Request:
Changed content type : application/json
- Changed property
domainContexts(array)
Changed items (array): Changed items (object):
- Changed property
domain(object)
Domain definition contains the list of relations to include and restricted ranges if any.
- Changed property
restrictedRanges(array)Note: List of restricted ranges
Changed items (object):
Changes from version 1.4.0 to version 1.5.0
WHAT'S CHANGED
POST /domains/session
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
POST /domains/admin/domain/{domainName}/upload
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
POST /domains/admin/domain/activate
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
POST /domains/admin/domain/{domainName}/pushAndActivate
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
GET /domains/admin/domain/{domainName}/export
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
GET /domains/admin/domain/{domainName}
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
POST /domains/admin/dataprovider/storefile
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
GET /domains
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
GET /domains/definition
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
POST /domains/getdomain/{relationVariableId}
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
POST /domains/checkConsistency/
Parameters:
Deleted: X-quotex-environment in header
Deprecated: Environment identifier. This parameter is deprecated and the environment will be automatically retrieved. If used the provided environment value will be checked against the environment value automatically found. This header should NOT be used to pass AppPortal environment value.
Changes from version 1.3.0 to version 1.4.0
WHAT'S CHANGED
POST /domains/getdomain/{relationVariableId}
Return Type:
Changed response: 200 OK
Domain values.
- Changed content type :
application/json- New required properties:
domainTypeClient
- New required properties:
domainTypeClient (string)ExtensionalUniversalConstrainedContinuous- Intervals
- Added property
homogeneousValueStatus(string)Note: Only if all values have the same value type otherwise null
Enum values:
AUTHORIZEDNOT_RECOMMENDEDFORBIDDEN- Added property
sortingCriteria(string)Note: Sorting criteria used
- Added property
Enum values:
KEEP_DOMAIN_DEFINITION_ORDERALPHABETICAL_ORDERREVERSE_ALPHABETICAL_ORDERASCENDING_ORDERDESCENDING_ORDERCHRONOLOGICAL_ORDERREVERSE_CHRONOLOGICAL_ORDERDESCR_ALPHABETICAL_ORDERDESCR_REVERSE_ALPHABETICAL_ORDER- Added property
open(boolean)
- Added property
True if the returned domain is open. This specifies whether the domain contains the values it
does not explicitly declare.
- Added property
partial(boolean)
True if only a part of the domain is returned. This specifies whether the returned domain contains or not all the possible values.
Changes from version 1.2.2 to version 1.3.0
WHAT'S NEW
GET /domains/definition
Changes from version 1.1.15 to version 1.2.2
WHAT'S CHANGED
POST /domains/admin/domain/activate
Return Type:
Changed response: 200 OK
list of activated domains with revision.
- Changed content type : `application/json`
Changed items (object):
- Added property `status` (string)
The activation status of the domain.
Enum values:
INACTIVEACTIVATION_REQUIREDACTIVE
POST /domains/admin/domain/{domainName}/pushAndActivate
Return Type:
Changed response : 200 OK
- Changed content type : `application/json`
- Added property `status` (string)
The activation status of the domain.
Enum values:
INACTIVEACTIVATION_REQUIREDACTIVE
GET /domains/admin/domain/{domainName}/export
Description:
This operation exports a domain JSON file with the provided domain name. By default it will export the lastest active domain file revision. A query parameter is available to get a specific domain file revision
Parameters:
Changed: revision in query
The domain file revision to export. Lastest active revision is exported if not provided.
GET /domains/admin/domain/{domainName}
Return Type:
Changed response : 200 OK
list of revisions for a domain.
- Changed content type :
application/json
Changed items (object):
The activation status of the domain.
Enum values:
INACTIVEACTIVATION_REQUIREDACTIVE
GET /domains
Description:
This operation return all available domains in their latest revision. By default the API will return only active revisions but this behavior can be changed by setting 'latest' query param to retrieve latest revisions even if they are not active
Parameters:
Added: latest in query
Return Type:
Changed response : 200 OK
Domain values.
- Changed content type :
application/json
Changed items (object):
- Added property
status(string)
The activation status of the domain.
Enum values:
INACTIVEACTIVATION_REQUIREDACTIVEChanges from version 1.1.12 to version 1.1.13
WHAT'S CHANGED
GET /DOMAINS
Return Type:
Changed response: 200 OK
Domain values.
- Changed content type :
application/jsonChanges from version 1.1.9 to version 1.1.11
WHAT'S CHANGED
POST /domains/getdomain/{relationVariableId}
Request:
Changed content type : application/json
- Changed property
assignments(array)Note: List of existing valuation
Changed items (object):
Variable valuation
* Changed property `value` (object)
See different GridValue subtypes definitions for more information.
Example: StringGridValue
Changed property `valueType` (string) Added enum values:
`Measure`
`CurrencyPerQuantity`
`MonetaryPerQuantity`- Changed property
dataProviderContext(object)
BETA - DataProvider context allows to configure the dataProvider and settings to use. (This definition may change in the future)
* Changed property `contextKeyValues` (array)
List of settings Changed items (object):
Settings definition (list of key/values)
* Changed property `dataProviderValue` (object)
* Changed property `value` (object)
See different GridValue subtypes definitions for more information. Example: StringGridValue
* Changed property `valueType` (string) Added enum values:
* `Measure``CurrencyPerQuantity`
`MonetaryPerQuantity`Return Type:
Changed response : 200 OK
Domain values.
- Changed content type :
application/json
Updated `ExtensionalDomain` :
* Changed property `domain` (array) Changed items (object):
Possible status for a GridValue
* Changed property `value` (object)
See different GridValue subtypes definitions for more information. Example: StringGridValue
Changed property `valueType` (string) Added enum values:
`Measure`
`CurrencyPerQuantity`
`MonetaryPerQuantity`POST /domains/checkConsistency/
Request:
Changed content type : application/json
Changed property domainContexts (array)
Changed items (array): Changed items (object):Domain context definitionChanged property `assignments` (array)List of existing valuation Changed items (object):Variable valuation
* Changed property `value` (object)
See different GridValue subtypes definitions for more information. Example: StringGridValueChanged property `valueType` (string) Added enum values:`Measure``CurrencyPerQuantity``MonetaryPerQuantity`
Changed property `dataProviderContext` (object)BETA - DataProvider context allows to configure the dataProvider and settings to use. (This definition may change in the future)Changed property `contextKeyValues` (array)List of settings Changed items (object):Settings definition (list of key/values)
* Changed property `dataProviderValue` (object)
* Changed property `value` (object)
See different GridValue subtypes definitions for more information. Example: StringGridValueChanged property `valueType` (string) Added enum values:`Measure``CurrencyPerQuantity``MonetaryPerQuantity`Changes from version 1.1.8 to version 1.1.9
WHAT'S CHANGED
POST /domains/getdomain/{relationVariableId}
Return Type:
Changed response : 200 OK
Domain values.
Changed content type : application/json
Updated `ExtensionalDomain` :
*Changed property `partial` (boolean)
true if only a part of the domain is returnedChanges from version 1.1.7 to version 1.1.8
WHAT'S NEW
GET /domains
WHAT'S DELETED
POST /domains/admin/domain/copyAndActivate/{toEnvironment}
WHAT'S CHANGED
POST /domains/getdomain/{relationVariableId}
Request:
Changed content type : application/json
- Changed property
domain(object)
Domain definition contains the list of relations to include and restricted ranges if any.* Changed property `relations` (array) List of relations Deleted property `revision` (integer)POST /domains/checkConsistency/
Request:
Changed content type : application/json
- Changed property
domainContexts(array)
Changed items (array):Changed items (object): the list of relations to include and restricted ranges if any.
* Changed property `relations` (array)> List of relations
Changed items (object):
`revision` (integer)
Relation Id
* Deleted property
Deprecated for removal, domains will be
based on latest version only. This parameter will be removed on release
version 12.15.Changes from version 1.1.4 to version 1.1.6
WHAT’S DEPRECATED
POST /domains/admin/domain/copyAndActivate/{toEnvironment}
WHAT’S CHANGED
POST /domains/admin/domain/activate
Return Type:
Changed response: 200 OK
list of activated domains with revision.
- Changed content type :
application/json
Changed items (object):
- Changed property
revision(integer)
Identifier of a domain revision.
POST /domains/admin/domain/{domainName}/pushAndActivate
Return Type:
Changed response : 200 OK
- Changed content type :
application/json - Changed property
revision(integer)
Identifier of a domain revision.
GET /domains/admin/domain/{domainName}
Return Type:
Changed response : 200 OK
list of revisions for a domain.
- Changed content type :
application/json
Changed items (object):
- Changed property
revision(integer)
Identifier of a domain revision.
POST /domains/admin/domain/copyAndActivate/{toEnvironment}
Request:
Changed content type : application/json
Changed items (object):
- Changed property
revision(integer)
Identifier of a domain revision.
Return Type:
Changed response : 200 OK
list of activated domains with revision.
- Changed content type :
application/json
Changed items (object):
- Changed property
revision(integer)
Identifier of a domain revision.
POST /domains/getdomain/{relationVariableId}
Request:
Changed content type : application/json
- Changed property
domain(object)
Domain definition contains the list of relations to include and restricted ranges if any.
- Changed property
relations(array)List of relations:
Changed items (object):
- Changed property
revision(integer)
Deprecated for removal, domains will be based on latest version only. This parameter will be removed on release version 12.15.
POST /domains/checkConsistency/
Request:
Changed content type : application/json
- Changed property
domainContexts(array)Changed items (array): Changed items (object):Domain context definition
Changed property
domain(object)
Domain definition contains the list of relations to include and restricted ranges if any.
- Changed property
relations(array)List of relations:
Changed items (object):
- Changed property
revision(integer)
Deprecated for removal, domains will be based on latest version only. This parameter will be removed on release version 12.15.
Changes from version 1.1.0 to version 1.1.1
WHAT'S CHANGED
POST /domains/session
Parameters:
Added: X-quotex-system-mode in header
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/admin/domain/{domainName}/upload
Parameters:
Added: X-quotex-system-mode in header
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/admin/domain/activate
Parameters:
Added: X-quotex-system-mode in header
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/admin/domain/{domainName}/pushAndActivate
Parameters:
Added: X-quotex-system-mode in header
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
GET /domains/admin/domain/{domainName}/export
Parameters:
Added: X-quotex-system-mode in header
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
GET /domains/admin/domain/{domainName}
Parameters:
header
X-quotex-system-mode
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/admin/domain/copyAndActivate/{toEnvironment}
Parameters:
header
X-quotex-system-mode
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/admin/dataprovider/storefile
Parameters:
header
X-quotex-system-mode
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/getdomain/{relationVariableId}
Parameters:
header
X-quotex-system-mode
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
POST /domains/checkConsistency/
Parameters:
Added: X-quotex-system-mode in header
Use this optional header to run an API in system mode. The user must have the API_SUPER_USER or AGREEMENT role to be able to use system mode.
Changes from version 1.0.0 to version 1.1.0
WHAT'S CHANGED
POST /domains/getdomain/{relationVariableId}
Request:
Changed content type : application/json
- Changed property
assignments(array)
List of existing valuationChanged items (object):> Variable valuation*
Changed property `value` (object) See different GridValue subtypes definitions for more information. Example: StringGridValue
property `valueType` (string)
`Attachment`
Added enum value:
*Changed
*
Changed property dataProviderContext (object)
BETA - DataProvider context allows to configure the dataProvider and settings to use. (This definition may change in the future)*Changedproperty `contextKeyValues` (array)
List of settings
(object):> Settings definition (list of key/values)*
Changed items
Changed
property `dataProviderValue` (object)*Changed property `value` (object)> See different GridValue subtypes definitions for
more information. Example: StringGridValue*
`valueType` (string)
`Attachment`
Added enum value:
Changed property
*Return Type:
Changed response : 200 OK
Domain values.
- Changed content type :
application/jsonUpdated `ExtensionalDomain` :* property `domain` (array) Changed items (object):* Changed property `value` (object) subtypes definitions for more information. Example: StringGridValue * * Changed property `valueType` (string) `Attachment` Added enum value:
POST /domains/checkConsistency/
Request:
Changed content type : application/json
Changed property domainContexts (array)
Changed items (array):Changed items (object):> Domain context definition* Changed property `assignments` (array)*Changed property`value` (object)
See different GridValue subtypes definitions for
more information. Example: StringGridValue*Changed property
`valueType` (string)Added enum value:*
`Attachment`*Changed property `dataProviderContext` (object)> BETA
- DataProvider context allows to configure the dataProvider and settings to use. (This definition may change in the future)*
`contextKeyValues` (array)> List of settings
Changed property
Changed items
(object):> Settings definition (list of key/values)
Changed property `dataProviderValue` (object)*
*
Changed
property `value` (object) definitions for more information. Example: StringGridValue
*Changed property `valueType` (string)Added enum
value:*`Attachment`